==> kubernetes-model-1.0.64-sources.jar: annotations/io/fabric8/kubernetes/api/model/FCVolumeSourceBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import javax.annotation.Generated;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import java.lang.Object;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import java.lang.Boolean;
import lombok.ToString;
import io.sundr.builder.annotations.Buildable;

public class FCVolumeSourceBuilder extends FCVolumeSourceFluentImpl<FCVolumeSourceBuilder> implements VisitableBuilder<FCVolumeSource,FCVolumeSourceBuilder>{

    FCVolumeSourceFluent<?> fluent;
    Boolean validationEnabled;

    public FCVolumeSourceBuilder(){
            this(true);
    }
    public FCVolumeSourceBuilder(Boolean validationEnabled){
            this(new FCVolumeSource(), validationEnabled);
    }
    public FCVolumeSourceBuilder(FCVolumeSourceFluent<?> fluent){
            this(fluent, true);
    }
    public FCVolumeSourceBuilder(FCVolumeSourceFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new FCVolumeSource(), validationEnabled);
    }
    public FCVolumeSourceBuilder(FCVolumeSourceFluent<?> fluent,FCVolumeSource instance){
            this(fluent, instance, true);
    }
    public FCVolumeSourceBuilder(FCVolumeSourceFluent<?> fluent,FCVolumeSource instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withFsType(instance.getFsType()); 
            fluent.withLun(instance.getLun()); 
            fluent.withReadOnly(instance.getReadOnly()); 
            fluent.withTargetWWNs(instance.getTargetWWNs()); 
            this.validationEnabled = validationEnabled; 
    }
    public FCVolumeSourceBuilder(FCVolumeSource instance){
            this(instance,true);
    }
    public FCVolumeSourceBuilder(FCVolumeSource instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withFsType(instance.getFsType()); 
            this.withLun(instance.getLun()); 
            this.withReadOnly(instance.getReadOnly()); 
            this.withTargetWWNs(instance.getTargetWWNs()); 
            this.validationEnabled = validationEnabled; 
    }

    public FCVolumeSource build(){
            FCVolumeSource buildable = new FCVolumeSource(fluent.getFsType(),fluent.getLun(),fluent.isReadOnly(),fluent.getTargetWWNs());
            io.fabric8.kubernetes.api.builder.ValidationUtils.validate(buildable);
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            FCVolumeSourceBuilder that = (FCVolumeSourceBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}

==> kubernetes-model-1.0.68-sources.jar: annotations/io/fabric8/kubernetes/api/model/FCVolumeSourceBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class FCVolumeSourceBuilder extends FCVolumeSourceFluentImpl<FCVolumeSourceBuilder> implements VisitableBuilder<FCVolumeSource,FCVolumeSourceBuilder>{

    FCVolumeSourceFluent<?> fluent;
    Boolean validationEnabled;

    public FCVolumeSourceBuilder(){
            this(true);
    }
    public FCVolumeSourceBuilder(Boolean validationEnabled){
            this(new FCVolumeSource(), validationEnabled);
    }
    public FCVolumeSourceBuilder(FCVolumeSourceFluent<?> fluent){
            this(fluent, true);
    }
    public FCVolumeSourceBuilder(FCVolumeSourceFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new FCVolumeSource(), validationEnabled);
    }
    public FCVolumeSourceBuilder(FCVolumeSourceFluent<?> fluent,FCVolumeSource instance){
            this(fluent, instance, true);
    }
    public FCVolumeSourceBuilder(FCVolumeSourceFluent<?> fluent,FCVolumeSource instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withFsType(instance.getFsType()); 
            fluent.withLun(instance.getLun()); 
            fluent.withReadOnly(instance.getReadOnly()); 
            fluent.withTargetWWNs(instance.getTargetWWNs()); 
            fluent.withWwids(instance.getWwids()); 
            this.validationEnabled = validationEnabled; 
    }
    public FCVolumeSourceBuilder(FCVolumeSource instance){
            this(instance,true);
    }
    public FCVolumeSourceBuilder(FCVolumeSource instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withFsType(instance.getFsType()); 
            this.withLun(instance.getLun()); 
            this.withReadOnly(instance.getReadOnly()); 
            this.withTargetWWNs(instance.getTargetWWNs()); 
            this.withWwids(instance.getWwids()); 
            this.validationEnabled = validationEnabled; 
    }

    public FCVolumeSource build(){
            FCVolumeSource buildable = new FCVolumeSource(fluent.getFsType(),fluent.getLun(),fluent.isReadOnly(),fluent.getTargetWWNs(),fluent.getWwids());
            io.fabric8.kubernetes.api.builder.ValidationUtils.validate(buildable);
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            FCVolumeSourceBuilder that = (FCVolumeSourceBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}
